sagemath_doc_html: SageMath documentation in HTML format
========================================================

Upon installation, this package builds the SageMath documentation
in HTML format.

It is a standard package.  It is built on every invocation
of ``make`` or ``make all``, but not on ``make build``.
The documentation build can also be run separately using
``make doc-html``.
